Documentation
¶
Overview ¶
Package parser provides a high-level SQL parser with functional options.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Option ¶
type Option func(*Parser)
Option configures a Parser using the functional options pattern.
func WithMaxErrors ¶
WithMaxErrors sets the maximum number of errors to collect before stopping.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package dialects implements SQL dialect parsers.
|
Package dialects implements SQL dialect parsers. |
|
Package grammars defines SQL dialect grammars.
|
Package grammars defines SQL dialect grammars. |
|
languages
|
|
|
graphql
Package graphql implements a GraphQL schema parser.
|
Package graphql implements a GraphQL schema parser. |
Click to show internal directories.
Click to hide internal directories.